@@ -1,13 +1,11 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
-from pathlib import Path
-from typing import Union
-
 import pandas as pd
 import structlog
-from openstef.data_classes.prediction_job import PredictionJobDataClass
 
+from openstef.data_classes.model_specifications import ModelSpecificationDataClass
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 from openstef.feature_engineering.feature_applicator import (
     OperationalPredictFeatureApplicator,
 )
@@ -25,7 +23,7 @@ from openstef.validation import validation
 def create_forecast_pipeline(
     pj: PredictionJobDataClass,
     input_data: pd.DataFrame,
-    trained_models_folder: Union[str, Path],
+    mlflow_tracking_uri: str,
 ) -> pd.DataFrame:
     """Create forecast pipeline
 
@@ -37,25 +35,24 @@ def create_forecast_pipeline(
     Args:
         pj (PredictionJobDataClass): Prediction job
         input_data (pd.DataFrame): Training input data (without features)
-        trained_models_folder (Path): Path where trained models are stored
-
+        mlflow_tracking_uri (str): MlFlow tracking URI
 
     Returns:
         pd.DataFrame with the forecast
 
     """
     # Load most recent model for the given pid
-    model, modelspecs = MLflowSerializer(
-        trained_models_folder=trained_models_folder
-    ).load_model(pj["id"])
-
-    return create_forecast_pipeline_core(pj, input_data, model)
+    model, model_specs = MLflowSerializer(
+        mlflow_tracking_uri=mlflow_tracking_uri
+    ).load_model(experiment_name=str(pj["id"]))
+    return create_forecast_pipeline_core(pj, input_data, model, model_specs)
 
 
 def create_forecast_pipeline_core(
     pj: PredictionJobDataClass,
     input_data: pd.DataFrame,
     model: OpenstfRegressor,
+    model_specs: ModelSpecificationDataClass,
 ) -> pd.DataFrame:
     """Create forecast pipeline (core)
 
@@ -69,6 +66,7 @@ def create_forecast_pipeline_core(
         pj (PredictionJobDataClass): Prediction job.
         input_data (pandas.DataFrame): Input data for the prediction.
         model (OpenstfRegressor): Model to use for this prediction.
+        model_specs (ModelSpecificationDataClass): Model specifications.
 
     Returns:
         forecast (pandas.DataFrame)
@@ -78,13 +76,14 @@ def create_forecast_pipeline_core(
     fallback_strategy = "extreme_day"  # this can later be expanded
 
     # Validate and clean data
-    validated_data = validation.validate(pj["id"], input_data)
+    validated_data = validation.validate(pj["id"], input_data, pj["flatliner_treshold"])
 
     # Add features
     data_with_features = OperationalPredictFeatureApplicator(
         # TODO use saved feature_names (should be saved while training the model)
         horizons=[pj["resolution_minutes"] / 60.0],
         feature_names=model.feature_names,
+        feature_modules=model_specs.feature_modules,
     ).add_features(validated_data)
 
     # Prep forecast input by selecting only the forecast datetime interval (this is much smaller than the input range)
@@ -95,7 +94,9 @@ def create_forecast_pipeline_core(
     )
 
     # Check if sufficient data is left after cleaning
-    if not validation.is_data_sufficient(data_with_features):
+    if not validation.is_data_sufficient(
+        data_with_features, pj["completeness_treshold"], pj["minimal_table_length"]
+    ):
         logger.warning(
             "Using fallback forecast",
             forecast_type="fallback",
